@@ -12,7 +12,7 @@ if( !any(class(x) == "XPtr") )
 
  pred <- factor(rep(NA,length(test)), levels=levels(cl))
  
- f <- function(x) {tmp <- order(x); tmp[1:min(k,length(tmp))]}
+ f <- function(x) {x[which(x==1)] <- NA; tmp <- order(x); tmp[1:min(k,length(tmp))]}
  nn <- applyXPtr(x, test, train, f)
  
  for(i in 1:length(test)){
@@ -27,7 +27,8 @@ if( !any(class(x) == "XPtr") )
     pred.cl <- names(votes)[idx]
     pred[i] <- pred.cl
   } else {
-    pred[i] <- cl[tmp]
+    if(length(tmp)>0)
+     pred[i] <- cl[tmp]
   }  
  }
  return(pred)
