@@ -12,17 +12,18 @@ if( !any(class(x) == "XPtr") )
 
  pred <- as.numeric(rep(NA,length(test)))
 
- f <- function(x) {tmp <- order(x); tmp[1:min(k,length(tmp))]}
+ f <- function(x) {x[which(x==1)] <- NA; tmp <- order(x); tmp[1:min(k,length(tmp))]}
  nn <- applyXPtr(x, test, train, f)
  
- g <- function(xx) {tmp <- order(xx); 
-   tmp <- tmp[1:min(k,length(tmp))]; xx[tmp]}
+ g <- function(x) {x[which(x==1)] <- NA; tmp <- order(x); 
+   tmp <- tmp[1:min(k,length(tmp))]; x[tmp]}
  ww <- applyXPtr(x, test, train, g)
  
  for(i in 1:length(test)){
   tmp <- nn[[i]]
   wt <- ww[[i]]
-  pred[i] <- weighted.mean(y[tmp], w=1-wt, na.rm=TRUE)
+  if(length(tmp)>0)
+   pred[i] <- weighted.mean(y[tmp], w=1-wt, na.rm=TRUE)
  }
  return(pred)
 }
